@@ -1,11 +1,17 @@
 from typing import Any, Dict, List, Optional, Type, Union
 
 import numpy as np
+import pandas as pd
 
+from dataquality.analytics import Analytics
+from dataquality.clients.api import ApiClient
 from dataquality.core._config import config
 from dataquality.exceptions import GalileoException
 from dataquality.loggers.data_logger import BaseGalileoDataLogger
 from dataquality.loggers.data_logger.base_data_logger import ITER_CHUNK_SIZE, DataSet
+from dataquality.loggers.data_logger.image_classification import (
+    ImageClassificationDataLogger,
+)
 from dataquality.loggers.logger_config.text_multi_label import (
     text_multi_label_logger_config,
 )
@@ -16,6 +22,7 @@ from dataquality.schemas.task_type import TaskType
 from dataquality.utils.helpers import check_noop
 
 DEFAULT_RANDOM_EMB_DIM = 2
+a = Analytics(ApiClient, config)  # type: ignore
 
 
 @check_noop
@@ -100,6 +107,43 @@ def log_data_sample(*, text: str, id: int, **kwargs: Any) -> None:
     data_logger.log_data_sample(text=text, id=id, **kwargs)
 
 
+@check_noop
+def log_image_dataset(
+    dataset: DataSet,
+    imgs_dir: str,
+    *,
+    imgs_location_colname: Optional[str] = "relpath",
+    batch_size: int = ITER_CHUNK_SIZE,
+    id: Union[str, int] = "id",
+    label: Union[str, int] = "label",
+    split: Optional[Split] = None,
+    meta: Optional[List[Union[str, int]]] = None,
+    **kwargs: Any,
+) -> None:
+    assert isinstance(
+        dataset, pd.DataFrame
+    ), "dataset must be a pandas DataFrame"  # TODO: add support for other data types
+    a.log_function("dq/log_image_dataset")
+    assert all(
+        [config.task_type, config.current_project_id, config.current_run_id]
+    ), "You must call dataquality.init before logging data"
+    data_logger = get_data_logger()
+    assert isinstance(data_logger, ImageClassificationDataLogger), (
+        "This method is only supported for image tasks. "
+        "Please use dq.log_samples for text tasks."
+    )
+    data_logger.log_image_dataset(
+        dataset=dataset,
+        imgs_dir=imgs_dir,
+        imgs_location_colname=imgs_location_colname,
+        batch_size=batch_size,
+        id=id,
+        label=label,
+        split=split,
+        meta=meta,
+    )
+
+
 @check_noop
 def log_dataset(
     dataset: DataSet,
@@ -173,6 +217,7 @@ def log_dataset(
     :param kwargs: See help(dq.get_data_logger().log_dataset) for more details here
     or dq.docs() for more general task details
     """
+    a.log_function("dq/log_dataset")
     assert all(
         [config.task_type, config.current_project_id, config.current_run_id]
     ), "You must call dataquality.init before logging data"
@@ -254,6 +299,10 @@ def set_labels_for_run(labels: Union[List[List[str]], List[str]]) -> None:
     In the multi-label case, the outer order (order of the tasks) must match the
     task-order of the task-probabilities logged as well.
     """
+    a.log_function("dq/set_labels_for_run")
+
+    if isinstance(labels[0], (int, np.integer)):
+        get_data_logger().logger_config.int_labels = True
     get_data_logger().logger_config.labels = labels
 
 
@@ -340,3 +389,15 @@ def set_split(split: Split, inference_name: Optional[str] = None) -> None:
     setattr(get_data_logger().logger_config, f"{split}_logged", True)
     # Set cur_inference_name before split for pydantic validation
     get_data_logger().logger_config.cur_split = split
+
+
+@check_noop
+def set_epoch_and_split(
+    epoch: int, split: Split, inference_name: Optional[str] = None
+) -> None:
+    """Set the current epoch and set the current split.
+    When set, logging data inputs/model outputs will use this if not logged explicitly
+    When setting split to inference, inference_name must be included
+    """
+    set_epoch(epoch)
+    set_split(split, inference_name)
